| Title: | American Psychological Association Thesis with R Markdown |
|---|---|
| Description: | Provides R Markdown document formats for theses that conform to American Psychological Association manuscript guidelines. |
| Authors: | Frederik Aust [aut, cre] (ORCID: <https://orcid.org/0000-0003-4900-788X>) |
| Maintainer: | Frederik Aust <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-09 06:48:38 UTC |
| Source: | https://github.com/crsh/apathe |
Template for homework in psychology at the University of Cologne in PDF format.
uoc_psych_homework_pdf( fig_caption = TRUE, number_sections = FALSE, toc = FALSE, keep_tex = FALSE, md_extensions = NULL, includes = NULL, ... )uoc_psych_homework_pdf( fig_caption = TRUE, number_sections = FALSE, toc = FALSE, keep_tex = FALSE, md_extensions = NULL, includes = NULL, ... )
fig_caption |
|
number_sections |
|
toc |
|
keep_tex |
Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., ‘.aux’) generated by LaTeX when compiling ‘.tex’ to
‘.pdf’. To keep these files, you may set |
md_extensions |
Markdown extensions to be added or removed from the
default definition of R Markdown. See the
|
includes |
Named list of additional content to include within the
document (typically created using the |
... |
Further arguments to pass to
|
When creating PDF documents the YAML option classoption is passed
to the class options of the LaTeX apa6 document class. In this case,
additional options are available. Refer to the apa6 document class
documentation
to find out about class options such as paper size.
R Markdown output format to pass to rmarkdown::render().
uoc_psych_thesis_pdf, bookdown::pdf_document2(), bookdown::word_document2()
Template for theses in psychology at the University of Cologne in PDF format.
uoc_psych_thesis_pdf( fig_caption = TRUE, number_sections = FALSE, keep_tex = TRUE, md_extensions = NULL, includes = NULL, ... )uoc_psych_thesis_pdf( fig_caption = TRUE, number_sections = FALSE, keep_tex = TRUE, md_extensions = NULL, includes = NULL, ... )
fig_caption |
|
number_sections |
|
keep_tex |
Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., ‘.aux’) generated by LaTeX when compiling ‘.tex’ to
‘.pdf’. To keep these files, you may set |
md_extensions |
Markdown extensions to be added or removed from the
default definition of R Markdown. See the
|
includes |
Named list of additional content to include within the
document (typically created using the |
... |
Further arguments to pass to
|
This document template includes by default the logo of the University of Cologne, which is protected by copyright. We have explicit permission to distribute the logo with this template, but unauthorized use of the logo is restricted to "students for work and presentations in the context of their studies" or "cases where the University of Cologne acts as an organizer or originator":
"The use of the university seal is permitted in cases where the University of Cologne acts as an organizer or originator. This regulation includes the use of the university seal by students for work and presentations in the context of their studies.
The use of the university seal by natural or legal persons outside the University of Cologne requires written permission and is only possible in cases where there is a sufficient connection to the University of Cologne. If permission is to be granted for advertising purposes, the interests of the University of Cologne must be given special consideration. The purpose, type, and extent of the permitted use must be specified in the permission. The permission must be in written form." (Rundschreiben-Nr. 54/2012)
You can use a different logo by setting the YAML option logo to the
path of the logo file. The logo should be a PDF file.
logo: file: "path/to/file.pdf" scale: 0.5
When creating PDF documents the YAML option classoption is passed
to the class options of the LaTeX apa6 document class. In this case,
additional options are available. Refer to the apa6 document class
documentation
to find out about class options such as paper size.
R Markdown output format to pass to rmarkdown::render().
uoc_psych_homework_pdf, bookdown::pdf_document2(), bookdown::word_document2()